==> control-toolbox-0.0.7.tar.gz: control-toolbox-0.0.7/README.md <==
# Python Control Systems Toolbox
[![Build Status](https://travis-ci.com/rushad7/control-toolbox.svg?branch=master)](https://travis-ci.com/rushad7/control-toolbox)
[![Documentation Status](https://readthedocs.org/projects/control-toolbox/badge/?version=latest)](https://control-toolbox.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/control-toolbox.svg)](https://badge.fury.io/py/control-toolbox)
![GitHub](https://img.shields.io/github/license/rushad7/control-toolbox)  

The `control-toolbox` is a Python Library for implementing and simulating various systems and control strategies.

## Current Supported Functionality:

- System modeling with Transfer Functions and State Space models.
- Time Domain Response of System with the following input signals: Impulse, Step, Ramp.
- System conversion, State Space model to Transfer Function
- Block diagram algebra: Series and Paralel.
- Stability analysis of the system.
- Root Locus Plot of the system.
- Frequency Response, Bode plot.
- Parameterization of systems.
- Pole-Zero Plot of systems.
- Feedback analysis.
- PID control.
- Observability, Controllability.

## Future Updates:
- Linear Quadratic Regulator.
- Kalman Filter.

## Project Links
Project Homepage: http://control-toolbox.rtfd.io/  
Documentation: [https://control-toolbox.readthedocs.io/](https://control-toolbox.readthedocs.io/)  
Source Code: [https://github.com/rushad7/control-toolbox](https://github.com/rushad7/control-toolbox)  

## Installation
### Pip
To install using pip, run the following command:

`pip install control-toolbox`

### Development
To get the latest unreleased version:

`git clone https://github.com/rushad7/control-toolbox.git`

==> control-toolbox-0.0.9.tar.gz: control-toolbox-0.0.9/README.md <==
# Python Control Systems Toolbox
[![Build Status](https://travis-ci.com/rushad7/control-toolbox.svg?branch=master)](https://travis-ci.com/rushad7/control-toolbox)
[![Documentation Status](https://readthedocs.org/projects/control-toolbox/badge/?version=latest)](https://control-toolbox.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/control-toolbox.svg)](https://badge.fury.io/py/control-toolbox)
![GitHub](https://img.shields.io/github/license/rushad7/control-toolbox)  

The `control-toolbox` is a Python Library for implementing and simulating various systems and control strategies.

## Current Supported Functionality:

- System modeling with Transfer Functions and State Space Representations.
- Time Domain Response.
- Frequency Response.
- System Representation conversion: State Space model to Transfer Function and vice versa.
- Block diagram algebra: Series and Parallel.
- Stability Analysis.
- Root Locus.
- Bode Plot.
- Parameterization of System.
- Pole-Zero / Eigenvalue plot of systems.
- Feedback analysis.
- PID control.
- Observability and Controllability.
- Full State Feedback
- Full State Observer
- Linear Quadratic Regulator(LQR)
- Linear Quadratic Estimator(LQE) / Kalman Filter

## Future Updates:
- Linear Quadratic Gaussian Control.
- Extended Kalman Filter.
- Unscented Kalman filter.
- Model Predictive Control.

## Project Links
Project Homepage: http://control-toolbox.rtfd.io/  
Documentation: [https://control-toolbox.readthedocs.io/](https://control-toolbox.readthedocs.io/)  

## Installation
### Pip
To install using pip, run the following command:

`pip install control-toolbox`

### Development
To get the latest unreleased version:

`git clone https://github.com/rushad7/control-toolbox.git`
